//LabPlot : ImageMagickDialog.h

#ifndef IMAGEMAGICKDIALOG_H
#define IMAGEMAGICKDIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include "MainWin.h"
#include "Dialog.h"

class ImageMagickDialog: public Dialog
{
	Q_OBJECT
public:
	ImageMagickDialog(MainWin *mw, QString fn=i18n("out.8bim"), int f=0, int sx=800, int sy=600,
		double r=0.0, const char *name=0);
public slots:
	void Apply() { apply_clicked(); accept(); }
private:
	QStringList formats;
	KComboBox *format;
	KLineEdit *filele, *xle, *yle, *rotle;
private slots:
	void saveSettings();
	void apply_clicked();
	void selectFile();
	void updateFilename(int index);
};

#endif //IMAGEMAGICKDIALOG_H
